import axios from 'axios'
import { getToken, getUserId, getCodeToken } from '@/utils/auth'
import { ElMessage } from 'element-plus'
import { useUserStore } from '@/store/user'
import router from '@/router'
let isMttoken
// create an axios instance
const service = axios.create({
  //baseURL: baseURL, // url = base url + request url
  // baseURL: 'http://106.14.243.117:9112',
  //baseURL: 'http://106.14.243.117:9111',
  baseURL: `${PLATFROM_CONFIG.baseNewUrl}`,
  // withCredentials: true, // send cookies when cross-domain requests
  timeout: 30000, // request timeout
  headers: {
    'Content-Type': 'application/json',
  },
})
// request interceptor
service.interceptors.request.use(
  (config: any) => {
    // config.headers.common["content-type"] = "application/json"
    if (config.istoken) {
      config.headers['appSecret'] = PLATFROM_CONFIG.appKeyString
      isMttoken = config.istoken
    }
    if (config.data) {
      config.data['OperatorId'] = getUserId()
      config.data['token'] = getCodeToken()
    }
    // do something before request is sent
    // config.headers['Content-Type'] = 'text/plain'
    if (getCodeToken() && !config.istoken) {
      config.headers['Authorization'] = getCodeToken()
    }
    if (useUserStore().token) {
      config.headers['Authorization'] = getToken()
    }
    return config
  },
  (error) => {
    // do something with request error

    return Promise.reject(error)
  }
)

// response interceptor
service.interceptors.response.use(
  /**
   * If you want to get http information such as headers or status
   * Please return  response => response
   */

  /**
   * Determine the request status by custom code
   * Here is just an example
   * You can also judge the status by HTTP Status Code
   */
  (response) => {
    const res = response.data

    // if the custom code is not 20000, it is judged as an error.
    if (res.code != 0) {
      ElMessage({
        message: res.message || 'Error',
        type: 'error',
        duration: 5 * 1000,
      })

      // 50008: Illegal token; 50012: Other clients logged in; 50014: Token expired;
      if (!isMttoken) {
        if (res.code == 500) {
          // to re-login
          ElMessage({
            message: '身份令牌过期或失效，即将重新登录',
            type: 'error',
            duration: 5 * 1000,
            onClose: () => {
              useUserStore().resetState()
              router.push(`/login`)
              location.reload()
            },
          })
        }
      }
      return Promise.reject(new Error(res.message || 'Error'))
    } else {
      return res
    }
  },
  (error) => {
    if (isMttoken) {
      // store.dispatch('user/setIsLogin', true)
    }
    return Promise.reject(error)
  }
)

export default service
